@@ -203,9 +203,6 @@ void toned_add_tone(struct TD *td, uint16_t *m)
    assert(td != NULL);
    assert(m[1] == PC_TONED_ST);
 
-   /* check that we don't have too many tone detectors */
-
-   assert(td->num_td < MD);
    num_td = td->num_td;
 
    /* check object ID is correct */
@@ -233,6 +230,7 @@ void toned_add_tone(struct TD *td, uint16_t *m)
    if (exists)
        d = &td->d[ind];		/* if exists replace with new toned */
    else {
+       assert(num_td < MD);	/* check that we don't have too many tone detectors */
        d = &td->d[num_td];	/* otherwise new tone decoder */
        td->num_td = ++num_td;	/* increment num tone detector counter */
    }
