@@ -1212,6 +1212,14 @@ static void ProcessVPBMessage(uint16_t mess[], unsigned short board)
 		putevt(&e);
 		break;
 
+	    case DSP_LOOP_FLASH:
+		assert(mess[0] == DSP_LLOOP_FLASH);
+		e.handle = mapdevtohndle(board, mess[2]);
+		e.type = VPB_LOOP_FLASH;
+		e.data = 0;
+		putevt(&e, VPB_MLOOP_FLASH);
+		break;
+
 	    default:
                 throw VpbException("ProcessVPBMessage: bad message %d", mess[1]);
 	} // switch
@@ -2072,6 +2080,18 @@ void WINAPI vpb_sethook_sync(VPBPortHandle handle, HookState hookstate)
 	GenericSleep(hookstate == VPB_FASTOFFHOOK ? 42 : 420);
 } //}}}
 
+void WINAPI vpb_set_flashtime(VPBPortHandle handle, uint16_t min, uint16_t max)
+{ //{{{
+	CheckHandle( handle, "vpb_set_flashtime" );
+
+	unsigned short	b,ch;
+	maphndletodev(handle, &b, &ch);
+
+	VPBREG	&reg = *vpb_c->vpbreg(b);
+	reg.hostdsp->SetFlashTime(ch, min, max);
+} //}}}
+
+
 void ring_station_async(int board, int port, int cadence)
 { //{{{
 	if( cadence == -1 )
@@ -2190,7 +2210,7 @@ int WINAPI vpb_adpcm_decode(
 		adpcm_decode(pv, linear, codes, size_adpcm*2);
 		*size_lin = size_adpcm*2;
 
-		delete codes;
+		delete [] codes;
 	}
 	catch(const Wobbly &w){
 		return RunTimeError(w,"vpb_adpcm_decode");
@@ -2226,7 +2246,7 @@ int WINAPI vpb_adpcm_encode(
 		adpcm_pack(codes, (unsigned short*)adpcm, size_linear/4);
 		*size_adpcm = size_linear/2;
 
-		delete codes;
+		delete [] codes;
 	}
 	catch(const Wobbly &w){
 		return RunTimeError(w,"vpb_adpcm_encode");
